-- NoIndex: true

--[[
    Lokasenna_GUI example

    - General demonstration
  - Tabs and layer sets
    - Subwindows
  - Accessing elements' parameters

]]--

-- Display a message in the console for debugging

function Msg(variable)
  reaper.ShowConsoleMsg(tostring(variable).."\n")
end

local info = debug.getinfo(1,'S');
script_path = info.source:match[[^@?(.*[\/])[^\/]-$]]

-- The Core library must be loaded prior to anything else
--[[
--------------------------------
 --REATRAK LOCAL GUI LIBRARY start
--------------------------------
local lib_path = script_path --reaper.GetExtState("Lokasenna_GUI", "lib_path_v2")
if not lib_path or lib_path == "" then
    reaper.MB("Couldn't load the Lokasenna_GUI library. Please run 'Script: Set Lokasenna_GUI v2 library path.lua' in your Action List.", "Whoops!", 0)
    return
end

loadfile(script_path .. "ReaTrak_Core.lua")()

GUI.req(script_path .. "ReaTrak_Classes/Class - Label.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Knob.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Tabs.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Slider.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Button.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Menubox.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Textbox.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Frame.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Options.lua")()
GUI.req(script_path .. "ReaTrak_Classes/Class - Window.lua")()

--------------------------------
 --REATRAK LOCAL GUI LIBRARY end
--------------------------------

--]]
--------------------------------
 --LOKASENNA GUI LIBRARY start
--------------------------------

local lib_path = reaper.GetExtState("Lokasenna_GUI", "lib_path_v2")
if not lib_path or lib_path == "" then
    reaper.MB("Couldn't load the Lokasenna_GUI library. Please run 'Script: Set Lokasenna_GUI v2 library path.lua' in your Action List.", "Whoops!", 0)
    return
end
loadfile(lib_path .. "Core.lua")()

GUI.req("Classes/Class - Label.lua")()
GUI.req("Classes/Class - Knob.lua")()
GUI.req("Classes/Class - Tabs.lua")()
GUI.req("Classes/Class - Slider.lua")()
GUI.req("Classes/Class - Button.lua")()
GUI.req("Classes/Class - Menubox.lua")()
GUI.req("Classes/Class - Textbox.lua")()
GUI.req("Classes/Class - Frame.lua")()
GUI.req("Classes/Class - Options.lua")()
GUI.req("Classes/Class - Window.lua")()

--------------------------------
 --LOKASENNA GUI LIBRARY end
--------------------------------

-- If any of the requested libraries weren't found, abort the script.
if missing_lib then return 0 end


scale_name = "Default"
------------------------------------
-------- Functions -----------------
------------------------------------

local function create_ix_scale()

    -- Set scale notes to no value for those not in the scale
    --note1 = -1
    note2 = -1
    note3 = -1
    note4 = -1
    note5 = -1
    note6 = -1
    note7 = -1
    note8 = -1
    note9 = -1
    note10 = -1
    note11 = -1
    note12 = -1
    
    key_choice = GUI.Val("set_key")
    scale_choice = GUI.Val("set_scale")
    reascale_choice = GUI.Val("reascale_chk")

--[[
Description: Convert current scale to ix_scale
Version: 1.0
Author: Lokasenna
Donation: https://paypal.me/Lokasenna
Changelog:
Links:
  Lokasenna's Website http://forum.cockos.com/member.php?u=10417
About:
  Converts the MIDI editor's current key snap scale into a .txt file
  for use in the IX MIDI effects included with Reaper. Output files are
  saved in the Reaper\Data\ix_scales folder.
Extensions:
--]]

  reaper.Main_OnCommand(40153, 0) --Item: Open in built-in MIDI editor (set default behavior in preferences)
  
  local cur_wnd = reaper.MIDIEditor_GetActive()
  if not cur_wnd then
    reaper.ShowMessageBox( "This script needs an active MIDI editor.", "No MIDI editor found", 0)
    return -1
  end
  
  local cur_take = reaper.MIDIEditor_GetTake(cur_wnd)
  
  -- Parse the scale string into something useful
  -- Size = number of non-zero values in the scale
   __, __, __, scale_name = reaper.MIDI_GetScale(cur_take, 0, 0, "")
  local __, scale_str = reaper.MIDIEditor_GetSetting_str(cur_wnd, "scale", "")
  local __, size = string.gsub(scale_str, "[^0]", "")
    
  scale_arr = {[0] = 0}
  for i = 1, size do
    scale_arr[i] = string.find(scale_str, "[^0]", scale_arr[i-1] + 1)
  end
   
  -- Adjust the values so that root = 0
  for i = 1, size do
    scale_arr[i] = scale_arr[i] - 1
    --Msg("Scale ".. i .. scale_arr[i].."\n")
    
    note2 = tonumber(scale_arr[2])
    note3 = tonumber(scale_arr[3])
    note4 = tonumber(scale_arr[4])
    note5 = tonumber(scale_arr[5])
    note6 = tonumber(scale_arr[6])
    note7 = tonumber(scale_arr[7])
    note8 = tonumber(scale_arr[8])
    note9 = tonumber(scale_arr[9])
    note10 = tonumber(scale_arr[10])
    note11 = tonumber(scale_arr[11])
    
    --if (scale_arr[i]) == false then scale_arr[i] = -1 end
    if note2 == nil then note2 = -1 end
    if note3 == nil then note3 = -1 end
    if note4 == nil then note4 = -1 end
    if note5 == nil then note5 = -1 end
    if note6 == nil then note6 = -1 end
    if note7 == nil then note7 = -1 end
    if note8 == nil then note8 = -1 end
    if note9 == nil then note9 = -1 end
    if note10 == nil then note10 = -1 end
    if note11 == nil then note11 = -1 end
    
  end
  
  --if scale_choice == 1 then note2=2  note3=4  note4=5  note5=7  note6=9 note7=11 end -- Major
  
  --Msg("note2= ".. note2)
  --Msg("note3= ".. note3)
  --Msg("note4= ".. note4)
  --Msg("note5= ".. note5)
  --Msg("note6= ".. note6)
  --Msg("note7= ".. note7)
  --Msg("note8= ".. note8)
  --Msg("note9= ".. note9)
  --Msg("note10= ".. note10)
  --Msg("note11= ".. note11)
  
  
  reaper.MIDIEditor_OnCommand(2,0) -- File: Close MIDI Editor window
end 


  

local function set_note_color()

  key_choice = GUI.Val("set_key")
  scale_choice = GUI.Val("set_scale")
  reascale_choice = GUI.Val("reascale_chk")

  mediaItem = reaper.GetSelectedMediaItem(0, 0)
  
  take = reaper.GetActiveTake(mediaItem)
  
  if scale_name == "" then scale_name = "Last Reascale" end
 
  retval, stringNeedBig = reaper.GetSetMediaItemTakeInfo_String( take, "P_NAME", "Midi Scale Snap Guide " .. selected_key .." ".. scale_name,1 )

  sel_track = reaper.GetSelectedTrack2( 0, 0, 1 )
  
  reascale_choice = GUI.Val("reascale_chk")
 
  if reascale_choice then   
    reaper.GetSetMediaTrackInfo_String(sel_track, "P_NAME", "Midi Scale Snap Guide " .. selected_key .." ".. scale_name, true)
    else
    reaper.GetSetMediaTrackInfo_String(sel_track, "P_NAME", "Midi Scale Snap Guide " .. selected_key .." ".. selected_scale, true)
  end 
  reaper.Main_OnCommand(40153, 0) --Item: Open in built-in MIDI editor (set default behavior in preferences)
  
  hwnd = reaper.MIDIEditor_GetActive()
  
  reaper.MIDIEditor_OnCommand(hwnd, 40739) -- color notes/CC by channel
  
  reaper.MIDIEditor_OnCommand(hwnd, 40214) -- Edit: Unselect all
  
  reaper.Main_OnCommand(40042,0) -- Transport: Go to start of project
  
  reaper.Main_OnCommand(40635,0) -- Time selection: Remove time selection  
  
end



function scale_track()

  start_time, end_time = reaper.GetSet_LoopTimeRange2(0, false, false, 0, 0, false)
  if start_time == end_time then
    reaper.MB( "Select Section of Track", "No Time Selected", 0 )
    reaper.defer(function () end)
    return
  end

  commandID2 = reaper.NamedCommandLookup("_SWS_CREATETRK1")
  reaper.Main_OnCommand(commandID2, 0) -- SWS: Create and select first track

  reaper.Main_OnCommand(40214,0) -- Insert new MIDI item... 40214
  --commandID1 = reaper.NamedCommandLookup("_RSa269108c0ba744d947b179c93a57c34399b55a43")
  --reaper.Main_OnCommand(commandID1, 0) -- Script: ReaTrak Go to start of previous region.lua "_RSa269108c0ba744d947b179c93a57c34399b55a43"  
  --retval_region, _, region_pos, region_end, region_name, region_index, region_color = reaper.EnumProjectMarkers3(0, 0)
  media = reaper.GetSelectedMediaItem(0, 0)
  take = reaper.GetMediaItemTake(media, 0)
  length = reaper.BR_GetMidiSourceLenPPQ(take) -- length of region/midi item
  
  --take = reaper.MIDIEditor_GetTake(midieditor)
  
  --count loop selected items or move to next region in Action
  
--Msg("region name")
--Msg(region_name)


     --chord, pos = nil, 0
     --chord, p = string.match(region_name, "=%s+([^\n]+)()", pos)
     --if not p then end
     --pos = p?
     

--]]
    
     
     -- root, chord = string.match(region_name, "(%w[#b]?)(.*)$")
     
     
     
     --if not chord or #chord == 0 then chord = "Maj" end
     --if not slash then slash = "" end


--Msg("root " ..root)

--Msg("chord " ..chord)

--Msg("slash " ..slash)

  --Msg("key_choice ".. key_choice)
  -- 60 = C3
  if key_choice == 1 then note1 = 60 -- "C" 
  elseif key_choice == 2 then note1 = 61 -- "C#"
  elseif key_choice == 3 then note1 = 61 -- "Db" 
  elseif key_choice == 4 then note1 = 62 -- "D"
  elseif key_choice == 5 then note1 = 63 -- "D#"
  elseif key_choice == 6 then note1 = 63 -- "Eb"
  elseif key_choice == 7 then note1 = 64 -- "E"
  elseif key_choice == 8 then note1 = 65 -- "F"
  elseif key_choice == 9 then note1 = 66 -- "F#"
  elseif key_choice == 10 then note1 = 66 -- "Gb"
  elseif key_choice == 11 then note1 = 67 -- "G"
  elseif key_choice == 12 then note1 = 68 -- "G#"
  elseif key_choice == 13 then note1 = 68 -- "Ab"
  elseif key_choice == 14 then note1 = 69 -- "A"
  elseif key_choice == 15 then note1 = 70 -- "A#"
  elseif key_choice == 16 then note1 = 70 -- "Bb"
  elseif key_choice == 17 then note1 = 71 -- "B"
  if not key_choice then end
  end
  

  --octave = note1 - slashnote
  --if octave > 12 and slashnote > 0 then slashnote = slashnote + 12 end
  
  --reaper.MIDI_InsertNote(take, true, false, 0, length -2, 1, note1, 50, false) -- Set root note1  
  key_names = { [1] = "C", [2] = "C#", [3] = "Db", [4] = "D", [5] = "D#", [6] = "Eb", [7] = "E", [8] = "F", [9] = "F#", [10] = "Gb", [11] = "G", [12] = "G#", [13] = "Ab", [14] = "A", [15] = "A#", [16] = "Bb", [17] = "B"}
  selected_key = key_names[key_choice]
    
  scale_names = { [1] = "Major", [2] = "Minor", [3] = "Harmonic Major", [4] = "Harmonic Minor", [5] = "Melodic Major", [6] = "Melodic Minor", [7] = "Ionian", [8] = "Dorian", [9] = "Phrygian", [10] = "Lydian", [11] = "Mixolydian", [12] = "Aeolian", [13] = "Locrian"}
  selected_scale = scale_names[scale_choice]
  
   if reascale_choice then create_ix_scale()  --Msg("using ix_scale")
    else
     --Msg("using scale choice")
     if scale_choice == 1 then note2=2  note3=4  note4=5  note5=7  note6=9 note7=11 end -- Major      
     if scale_choice == 2 then note2=2  note3=3  note4=5  note5=7  note6=8 note7=10 end -- Minor      
     if scale_choice == 3 then note2=2  note3=4  note4=5  note5=7  note6=9 note7=11 end -- Harmonic Major
     if scale_choice == 4 then note2=2  note3=3  note4=5  note5=7  note6=8 note7=11 end -- Harmonic Minor      
     if scale_choice == 5 then note2=2  note3=4  note4=5  note5=7  note6=9 note7=11 end -- Melodic Major
     if scale_choice == 6 then note2=2  note3=4  note4=5  note5=7  note6=8 note7=10 end -- Melodic Minor      
  
     if scale_choice == 7 then note2=2  note3=4  note4=5  note5=7  note6=9 note7=11 end -- Ionian      
     if scale_choice == 8 then note2=2  note3=3  note4=5  note5=7  note6=9 note7=11 end -- Dorian      
     if scale_choice == 9 then note2=1  note3=3  note4=5  note5=7  note6=8 note7=10 end -- Phrygian      
     if scale_choice == 10 then note2=2  note3=4  note4=6  note5=7  note6=9 note7=11 end -- Lydian      
     if scale_choice == 11 then note2=2  note3=4  note4=5  note5=7  note6=9 note7=10 end -- Mixolydian
     if scale_choice == 11 then note2=2  note3=3  note4=5  note5=7  note6=8 note7=10 end -- Aeolian      
     if scale_choice == 13 then note2=1  note3=3  note4=5  note5=6  note6=8 note7=10 end -- Locrian      
   end


  --Msg("Note1= ".. note1)

  if note1-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1-84, 50, false) end-- Set root note1  C-24
  if note2 > 0 and note1+note2-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2-84, 50, false) end -- chord note 2
  if note3 > 0 and note1+note3-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3-84, 50, false) end -- chord note 3 
  if note4 > 0 and note1+note4-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4-84, 50, false) end -- chord note 4
  if note5 > 0 and note1+note5-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5-84, 50, false) end -- chord note 5
  if note6 > 0 and note1+note6-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6-84, 50, false) end -- chord note 6
  if note7 > 0 and note1+note7-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7-84, 50, false) end -- chord note 7
  if note8 > 0 and note1+note8-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8-84, 50, false) end -- chord note 8 
  if note9 > 0 and note1+note9-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9-84, 50, false) end -- chord note 9
  if note10 > 0 and note1+note10-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10-84, 50, false) end -- chord note 10
  if note11 > 0 and note1+note11-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11-84, 50, false) end -- chord note 11
  if note12 > 0 and note1+note12-84 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12-84, 50, false) end -- chord note 12
  

  if note1-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1-72, 50, false) end-- Set root note1  C-12
  if note2 > 0 and note1+note2-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2-72, 50, false) end -- chord note 2
  if note3 > 0 and note1+note3-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3-72, 50, false) end -- chord note 3 
  if note4 > 0 and note1+note4-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4-72, 50, false) end -- chord note 4
  if note5 > 0 and note1+note5-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5-72, 50, false) end -- chord note 5
  if note6 > 0 and note1+note6-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6-72, 50, false) end -- chord note 6
  if note7 > 0 and note1+note7-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7-72, 50, false) end -- chord note 7
  if note8 > 0 and note1+note8-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8-72, 50, false) end -- chord note 8 
  if note9 > 0 and note1+note9-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9-72, 50, false) end -- chord note 9
  if note10 > 0 and note1+note10-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10-72, 50, false) end -- chord note 10
  if note11 > 0 and note1+note11-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11-72, 50, false) end -- chord note 11
  if note12 > 0 and note1+note12-72 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12-72, 50, false) end -- chord note 12
  
  
  reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1-60, 50, false) -- Set root note1  C0
  if note2 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2-60, 50, false) end -- chord note 2
  if note3 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3-60, 50, false) end -- chord note 3 
  if note4 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4-60, 50, false) end -- chord note 4
  if note5 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5-60, 50, false) end -- chord note 5
  if note6 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6-60, 50, false) end -- chord note 6
  if note7 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7-60, 50, false) end -- chord note 7
  if note8 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8-60, 50, false) end -- chord note 8 
  if note9 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9-60, 50, false) end -- chord note 9
  if note10 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10-60, 50, false) end -- chord note 10
  if note11 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11-60, 50, false) end -- chord note 11
  if note12 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12-60, 50, false) end -- chord note 12
   
  reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1-48, 50, false) -- Set root note1  C12
  if note2 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2-48, 50, false) end -- chord note 2
  if note3 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3-48, 50, false) end -- chord note 3 
  if note4 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4-48, 50, false) end -- chord note 4
  if note5 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5-48, 50, false) end -- chord note 5
  if note6 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6-48, 50, false) end -- chord note 6
  if note7 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7-48, 50, false) end -- chord note 7
  if note8 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8-48, 50, false) end -- chord note 8 
  if note9 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9-48, 50, false) end -- chord note 9
  if note10 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10-48, 50, false) end -- chord note 10
  if note11 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11-48, 50, false) end -- chord note 11
  if note12 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12-48, 50, false) end -- chord note 12
  
  reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1-36, 50, false) -- Set root note1  C24
  if note2 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2-36, 50, false) end -- chord note 2
  if note3 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3-36, 50, false) end -- chord note 3 
  if note4 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4-36, 50, false) end -- chord note 4
  if note5 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5-36, 50, false) end -- chord note 5
  if note6 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6-36, 50, false) end -- chord note 6
  if note7 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7-36, 50, false) end -- chord note 7
  if note8 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8-36, 50, false) end -- chord note 8 
  if note9 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9-36, 50, false) end -- chord note 9
  if note10 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10-36, 50, false) end -- chord note 10
  if note11 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11-36, 50, false) end -- chord note 11
  if note12 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12-36, 50, false) end -- chord note 12
  
  reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1-24, 50, false) -- Set root note1  C36
  if note2 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2-24, 50, false) end -- chord note 2
  if note3 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3-24, 50, false) end -- chord note 3 
  if note4 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4-24, 50, false) end -- chord note 4
  if note5 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5-24, 50, false) end -- chord note 5
  if note6 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6-24, 50, false) end -- chord note 6
  if note7 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7-24, 50, false) end -- chord note 7
  if note8 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8-24, 50, false) end -- chord note 8 
  if note9 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9-24, 50, false) end -- chord note 9
  if note10 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10-24, 50, false) end -- chord note 10
  if note11 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11-24, 50, false) end -- chord note 11
  if note12 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12-24, 50, false) end -- chord note 12

  reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1-12, 50, false) -- Set root note1  C48
  if note2 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2-12, 50, false) end -- chord note 2
  if note3 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3-12, 50, false) end -- chord note 3 
  if note4 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4-12, 50, false) end -- chord note 4
  if note5 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5-12, 50, false) end -- chord note 5
  if note6 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6-12, 50, false) end -- chord note 6
  if note7 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7-12, 50, false) end -- chord note 7
  if note8 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8-12, 50, false) end -- chord note 8 
  if note9 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9-12, 50, false) end -- chord note 9
  if note10 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10-12, 50, false) end -- chord note 10
  if note11 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11-12, 50, false) end -- chord note 11
  if note12 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12-12, 50, false) end -- chord note 12
 
  reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1, 50, false) -- Set root note1  C60
  if note2 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2, 50, false) end -- chord note 2
  if note3 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3, 50, false) end -- chord note 3 
  if note4 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4, 50, false) end -- chord note 4
  if note5 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5, 50, false) end -- chord note 5
  if note6 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6, 50, false) end -- chord note 6
  if note7 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7, 50, false) end -- chord note 7
  if note8 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8, 50, false) end -- chord note 8 
  if note9 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9, 50, false) end -- chord note 9
  if note10 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10, 50, false) end -- chord note 10
  if note11 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11, 50, false) end -- chord note 11
  if note12 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12, 50, false) end -- chord note 12

  reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+12, 50, false) -- Set root note1 C72 
  if note2 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2+12, 50, false) end -- chord note 2
  if note3 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3+12, 50, false) end -- chord note 3 
  if note4 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4+12, 50, false) end -- chord note 4
  if note5 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5+12, 50, false) end -- chord note 5
  if note6 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6+12, 50, false) end -- chord note 6
  if note7 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7+12, 50, false) end -- chord note 7
  if note8 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8+12, 50, false) end -- chord note 8 
  if note9 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9+12, 50, false) end -- chord note 9
  if note10 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10+12, 50, false) end -- chord note 10
  if note11 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11+12, 50, false) end -- chord note 11
  if note12 > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12+12, 50, false) end -- chord note 12

  if note1+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+24, 50, false) end-- Set root note1  C84
  if note2 > 0 and note1+note2+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2+24, 50, false) end -- chord note 2
  if note3 > 0 and note1+note3+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3+24, 50, false) end -- chord note 3 
  if note4 > 0 and note1+note4+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4+24, 50, false) end -- chord note 4
  if note5 > 0 and note1+note5+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5+24, 50, false) end -- chord note 5
  if note6 > 0 and note1+note6+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6+24, 50, false) end -- chord note 6
  if note7 > 0 and note1+note7+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7+24, 50, false) end -- chord note 7
  if note8 > 0 and note1+note3+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8+24, 50, false) end -- chord note 8 
  if note9 > 0 and note1+note4+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9+24, 50, false) end -- chord note 9
  if note10 > 0 and note1+note5+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10+24, 50, false) end -- chord note 10
  if note11 > 0 and note1+note6+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11+24, 50, false) end -- chord note 11
  if note12 > 0 and note1+note7+24 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12+24, 50, false) end -- chord note 12

  if note1+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+36, 50, false) end-- Set root note1  C96
  if note2 > 0 and note1+note2+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2+36, 50, false) end -- chord note 2
  if note3 > 0 and note1+note3+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3+36, 50, false) end -- chord note 3 
  if note4 > 0 and note1+note4+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4+36, 50, false) end -- chord note 4
  if note5 > 0 and note1+note5+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5+36, 50, false) end -- chord note 5
  if note6 > 0 and note1+note6+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6+36, 50, false) end -- chord note 6
  if note7 > 0 and note1+note7+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7+36, 50, false) end -- chord note 7
  if note8 > 0 and note1+note3+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8+36, 50, false) end -- chord note 8 
  if note9 > 0 and note1+note4+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9+36, 50, false) end -- chord note 9
  if note10 > 0 and note1+note5+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10+36, 50, false) end -- chord note 10
  if note11 > 0 and note1+note6+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11+36, 50, false) end -- chord note 11
  if note12 > 0 and note1+note7+36 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12+36, 50, false) end -- chord note 12
    
  if note1+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+48, 50, false) end-- Set root note1  C108
  if note2 > 0 and note1+note2+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2+48, 50, false) end -- chord note 2
  if note3 > 0 and note1+note3+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3+48, 50, false) end -- chord note 3 
  if note4 > 0 and note1+note4+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4+48, 50, false) end -- chord note 4
  if note5 > 0 and note1+note5+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5+48, 50, false) end -- chord note 5
  if note6 > 0 and note1+note6+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6+48, 50, false) end -- chord note 6
  if note7 > 0 and note1+note7+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7+48, 50, false) end -- chord note 7
  if note8 > 0 and note1+note3+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8+48, 50, false) end -- chord note 8 
  if note9 > 0 and note1+note4+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9+48, 50, false) end -- chord note 9
  if note10 > 0 and note1+note5+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10+48, 50, false) end -- chord note 10
  if note11 > 0 and note1+note6+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11+48, 50, false) end -- chord note 11
  if note12 > 0 and note1+note7+48 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12+48, 50, false) end -- chord note 12
    
  if note1+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+60, 50, false) end-- Set root note1  C120
  if note2 > 0 and note1+note2+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note2+60, 50, false) end -- chord note 2
  if note3 > 0 and note1+note3+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note3+60, 50, false) end -- chord note 3 
  if note4 > 0 and note1+note4+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note4+60, 50, false) end -- chord note 4
  if note5 > 0 and note1+note5+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note5+60, 50, false) end -- chord note 5
  if note6 > 0 and note1+note6+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note6+60, 50, false) end -- chord note 6
  if note7 > 0 and note1+note7+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note7+60, 50, false) end -- chord note 7  
  if note8 > 0 and note1+note3+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note8+60, 50, false) end -- chord note 8 
  if note9 > 0 and note1+note4+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note9+60, 50, false) end -- chord note 9
  if note10 > 0 and note1+note5+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note10+60, 50, false) end -- chord note 10
  if note11 > 0 and note1+note6+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note11+60, 50, false) end -- chord note 11
  if note12 > 0 and note1+note7+60 < 127 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 3, note1+note12+60, 50, false) end -- chord note 12  


 
  
 
  

--  if noteroot > 0 then reaper.MIDI_InsertNote(take, true, false, 0, length -2, 1, note1-noteroot, 50, false) end -- chord note 7
  
  --reaper.MIDI_DeleteNote(take, note1)  -- Delete set root note 
  --reaper.MIDI_Sort(take)
 
  --commandID4 = reaper.NamedCommandLookup("_RSce47da3c9b1238de71cc94a1cb99732b9abd5e41")
  --reaper.Main_OnCommand(commandID4, 0) -- Script: ReaTrak Go to start of next region.lua  
  set_note_color()  
  reaper.PreventUIRefresh(-1)
  


end


  

local function fade_lbl()
   
   -- Fade out the label
    if GUI.elms.my_lbl.z == 3 then
        GUI.elms.my_lbl:fade(1, 3, 6)
        
    -- Bring it back
    else
        GUI.elms.my_lbl:fade(1, 3, 6, -3)
    end
    
end


local function btn_click()

    -- Set scale notes to no value for those not in the scale
    note1 = -1
    note2 = -1
    note3 = -1
    note4 = -1
    note5 = -1
    note6 = -1
    note7 = -1
    note8 = -1
    note9 = -1
    note10 = -1
    note11 = -1
    note12 = -1    
    
    
    key_choice = GUI.Val("set_key")
    scale_choice = GUI.Val("set_scale")
    reascale_choice = GUI.Val("reascale_chk")
    --Msg("key = " .. key_choice)
    --Msg("scale = " .. scale_choice)
    --Msg("function scale_track()")
    scale_track()
    
    -- Open the Window element
  --GUI.elms.wnd_test:open()
  
end


local function wnd_OK()

    -- Close the Window element
    GUI.elms.wnd_test:close()
    
end


-- Returns a list of every element on the specified z-layer and
-- a second list of each element's values
local function get_values_for_tab(tab_num)
    
  -- The '+ 2' here is just to translate from a tab number to its' 
  -- associated z layer. More complicated scripts would have to 
  -- actually access GUI.elms.tabs.z_sets[tab_num] and iterate over
  -- the table's contents (see the call to GUI.elms.tabs:update_sets
  -- below)
    local strs_v, strs_val = {}, {}
  for k, v in pairs(GUI.elms_list[tab_num + 2]) do
    
        strs_v[#strs_v + 1] = v
    local val = GUI.Val(v)
    if type(val) == "table" then
      local strs = {}
      for k, v in pairs(val) do
                local str = tostring(v) 
                
                -- For conciseness, reduce boolean values to T/F
        if str == "true" then
                    str = "T"
                elseif str == "false" then
                    str = "F"
                end
                strs[#strs + 1] = str
      end
      val = table.concat(strs, ", ")
    end
        
        -- Limit the length of the returned string so it doesn't
        -- spill out past the edge of the window
    strs_val[#strs_val + 1] = string.len(tostring(val)) <= 35
                                and tostring(val)
                                or  string.sub(val, 1, 32) .. "..."
    
  end
    
    return strs_v, strs_val
    
end




------------------------------------
-------- Window settings -----------
------------------------------------


GUI.name = "Midi Scale Snap Guide"
GUI.x, GUI.y, GUI.w, GUI.h = 0, 0, 432, 260
GUI.anchor, GUI.corner = "mouse", "C"


--[[  

  Button    z,   x,   y,   w,   h, caption, func[, ...]
  Checklist  z,   x,   y,   w,   h, caption, opts[, dir, pad]
  Frame    z,   x,   y,   w,   h[, shadow, fill, color, round]
  Knob    z,   x,   y,   w,   caption, min, max, default[, inc, vals]  
  Label    z,   x,   y,    caption[, shadow, font, color, bg]
  Menubox    z,   x,   y,   w,   h, caption, opts
  Radio    z,   x,   y,   w,   h, caption, opts[, dir, pad]
  Slider    z,   x,   y,   w,   caption, min, max, defaults[, inc, dir]
  Tabs    z,   x,   y,     tab_w, tab_h, opts[, pad]
  Textbox    z,   x,   y,   w,   h[, caption, pad]
    Window      z,  x,  y,  w,  h,  caption, z_set[, center]
  
]]--


-- Elements can be created in any order you want. I find it easiest to organize them
-- by tab, or by what part of the script they're involved in.




------------------------------------
-------- General elements ----------
------------------------------------


--GUI.New("tabs",   "Tabs",     1, 0, 0, 64, 20, "Stuff,Sliders,Options", 16)
GUI.New("tab_bg",  "Frame",    2, 0, 0, 448, 20, false, true, "elm_bg", 0)
GUI.New("my_btn",   "Button",     1, 118, 28, 186, 20, "Create Midi Scale Snap Guide", btn_click)
--GUI.elms.my_btn.col_txt = "btn_txt1"
GUI.elms.my_btn.col_fill = "green"
GUI.New("btn_frm",  "Frame",    1, 0, 56, GUI.w, 4, true, true)

-- Telling the tabs which z layers to display
-- See Classes/Tabs.lua for more detail

-- Notice that layers 1 and 2 aren't assigned to a tab; this leaves them visible
-- all the time.




------------------------------------
-------- Tab 1 Elements ------------
------------------------------------
    


GUI.New("my_lbl",   "Label",     3, 115, 56, "Choose Key & Scale", true, 1)
--GUI.New("my_knob",   "Knob",     3, 64, 112, 48, "Volume", 0, 11, 44, 0.25)
GUI.New("set_scale",   "Menubox",     3, 86, 176, 124, 20, "Scale:", "Major,Minor,Harmonic Major,Harmonic Minor,Melodic Major,Melodic Minor,Ionian,Dorian,Phrygian,Lydian,Mixolydian,Aeolian,Locrian")
--GUI.New("my_btn2",  "Button",       3, 256, 256, 64, 20, "Click me!", fade_lbl)
--GUI.New("my_txt",   "Textbox",     3, 96, 224, 96, 20, "Text:", 4)
--GUI.New("my_frm",   "Frame",     3, 16, 288, 192, 128, true, false, "elm_frame", 4)
GUI.New("set_key",  "Radio",    3, 10, 104, 410, 64, "Key", "C,C#,Db,D,D#,Eb,E,F,F#,Gb,G,G#,Ab,A,A#,Bb,B", "h", 4)
GUI.New("reascale_chk",   "Checklist",   3, 240, 182, 180, 50, "Use Current/last Reascale:", "Yes", "v", 4)








------------------------------------
-------- Main functions ------------
------------------------------------


-- This will be run on every update loop of the GUI script; anything you would put
-- inside a reaper.defer() loop should go here. (The function name doesn't matter)
local function Main()
  
  -- Prevent the user from resizing the window
  if GUI.resized then
    
    -- If the window's size has been changed, reopen it
    -- at the current position with the size we specified
    local __,x,y,w,h = gfx.dock(-1,0,0,0,0)
    gfx.quit()
    gfx.init(GUI.name, GUI.w, GUI.h, 0, x, y)
    GUI.redraw_z[0] = true
  end    
  
end


-- Open the script window and initialize a few things
GUI.Init()

-- Tell the GUI library to run Main on each update loop
-- Individual elements are updated first, then GUI.func is run, then the GUI is redrawn
GUI.func = Main

-- How often (in seconds) to run GUI.func. 0 = every loop.
GUI.freq = 0

reaper.defer(function () end)

-- Start the main loop
GUI.Main()


